/****************************************************\
|*Head Crab Me                                      *|
|*Created By: Sam Tsuki                             *|
|*                                                  *|
|* Have Fun,                                        *|
|*           Sam Tsuki                              *|
\****************************************************/

/*
Description:
This plugin turns the player if he has enough health into a Head Crab.
Head Crabs Have extra health, extra armor, extra speed, less gravity, fulltime duck, infection and
knife only.
If infection is enabled, when a Head Crab attacks a player with HP lower than the infect hp CVAR,
the player is turned into a Zombie and switchs teams.
If there's only one human in a team, he can't be infected.
Head Crabs and Zombies have special vision and knife models.
Head Crabs have special bomb and HE grenade models nad they can move when they're planting.
Zombies have special knife models, however they can't throw HE gernades ,plant or pick up the bomb.
At the end of the round if a Zombie is alive he will die and return to his team.

CMDs:
say /hcmmenu			// Shows user's interface
say /headcrabme			// Turn into a Head Crab
say /unheadcrabme		// Turn back into human
hc_toggle <0|1> 		// ADMINMENU_ACCESS, Turns Head Crab Me plugin OFF/ON
hc_player <NAME|@TEAM|ALL> 	// ADMINMENU_ACCESS, Turns the target into a Head Crab
unhc_player <NAME|@TEAM|ALL> 	// ADMINMENU_ACCESS, Turns the target back into a human and kills him

CVARs:
hc_switch 1			// Enables the plugin
hc_minhealth 100		// The minimum health needed to turn into a headcrab
hc_health 300			// Head Crabs' health
hc_armor 500			// Head Crabs' armor
hc_speed 1000			// Head Crabs' speed (Change this depending on if hc_duck is on or off)
hc_gravity 45			// Head Crabs' gravity %
hc_duck 1			// Enables fulltime duck for Head Crabs
hc_infection 1			// Enables infection mode for Head Crabs
hc_infect_hp 25			// Maximum health for humans to be infected by Head Crabs
zm_health 600			// Zombies' health
zm_armor 350			// Zombies' armor
zm_speed 300			// Zombies' speed
zm_gravity 60			// Zombies' gravity %
zm_infection 1			// Enables infection mode for zombies
zm_infect_hp 50			// Maximum health for humans to be infected by Zombies

human_losefrags 1		// A Head Crab will lose this amount of frags if used /unheadcrabme command
hc_vision 125			// Zoom vision for Head Crabs
hc_red 255			// Red value for Head Crabs' screen
hc_green 0			// Green value for Head Crabs' screen
hc_blue 0			// Blue value for Head Crabs' screen
hc_tint 100			// Tint value for Head Crabs' screen
zm_vision 150			// Zoom vision for Zombies
zm_red 255			// Red value for Zombies' screen
zm_green 0			// Green value for Zombies' screen
zm_blue 0			// Blue value for Zombies' screen
zm_tint 150			// Tint value for Zombies' screen

hc_teams_mode 0			// Enables Teams Mode (Head Crabs a whole team changed everyround)
hc_sounds 1			// Enables Head Crab Me sounds
*/

#include <amxmodx>
#include <amxmisc>
#include <engine>
#include <fakemeta>
#include <fun>
#include <csx>
#include <cstrike>

#define PLUGIN "Head Crab Me"
#define VERSION "1.0"
#define AUTHOR "Sam Tsuki"

#define MAX_PLAYERS 33
#define MAX_WEAPONS 32

#define ADMINMENU_ACCESS ADMIN_KICK

#define HCMINHEALTH_ADD 10
#define HCHEALTH_ADD 10
#define HCARMOR_ADD 10
#define HCSPEED_ADD 20
#define HCGRAVITY_ADD 5
#define HCINFECTHP_ADD 5
#define ZMHEALTH_ADD 10
#define ZMARMOR_ADD 10
#define ZMSPEED_ADD 10
#define ZMGRAVITY_ADD 5
#define ZMINFECTHP_ADD 5

#define HUMANLOSE_ADD 1
#define HCVISION_ADD 5
#define HCRED_ADD 5
#define HCGREEN_ADD 5
#define HCBLUE_ADD 5
#define ZMVISION_ADD 5
#define ZMRED_ADD 5
#define ZMGREEN_ADD 5
#define ZMBLUE_ADD 5

// MODELS
new headcrab_model_t[52] = "models/player/headcrabme_t/headcrabme_t.mdl"
new shorthc_model_t[31] = "headcrabme_t"
new headcrab_model_ct[52] = "models/player/headcrabme_ct/headcrabme_ct.mdl"
new shorthc_model_ct[31] = "headcrabme_ct"
new headcrab_bomb[52] = "models/headcrabme/headcrab_bomb.mdl"
new headcrab_t_knife[52] = "models/headcrabme/headcrab_t_knife.mdl"
new headcrab_t_hegrenade[52] = "models/headcrabme/headcrab_t_hegrenade.mdl"
new headcrab_ct_knife[52] = "models/headcrabme/headcrab_ct_knife.mdl"
new headcrab_ct_hegrenade[52] = "models/headcrabme/headcrab_ct_hegrenade.mdl"
new zombie_model_t[52] = "models/player/zombieme_t/zombieme_t.mdl"
new shortzm_model_t[31] = "zombieme_t"
new zombie_model_ct[52] = "models/player/zombieme_ct/zombieme_ct.mdl"
new shortzm_model_ct[31] = "zombieme_ct"
new zombie_knife[52] = "models/headcrabme/zombie_knife.mdl"
new bomb_model[52] = "models/gib_skull.mdl"
new hegrenade_model[52] = "models/gib_legbone.mdl"

// PCVARs
new hc_switch, hc_minhealth, hc_health, hc_armor, hc_speed, hc_gravity, hc_duck, hc_infection, hc_infect_hp, zm_health, zm_armor, zm_speed, zm_gravity, zm_infection, zm_infect_hp
new human_losefrags, hc_vision, hc_red, hc_green, hc_blue, hc_tint, zm_vision, zm_red, zm_green, zm_blue, zm_tint
new hc_teams_mode, hc_sounds, amx_show_activity

// GLOBAL VARIABLES
new g_headcrab[MAX_PLAYERS], g_zombie[MAX_PLAYERS]
new MsgSetFOV, msgtext
new bool:freezetime = false, latejoin
new bomber, CsTeams:team[MAX_PLAYERS]
new block_use[MAX_PLAYERS]
new hc_teamturn[3] = "CT"
new MenuID[MAX_PLAYERS]
new VIP
new blood_drop, blood_spray
new g_sound[MAX_PLAYERS]

//BLOCKED SOUNDS
static g_blockedsounds[] = {
	"weapons/knife_deploy1.wav",
	"weapons/knife_hit1.wav",
	"weapons/knife_hit2.wav",
	"weapons/knife_hit3.wav",
	"weapons/knife_hit4.wav",
	"weapons/knife_hitwall1.wav",
	"weapons/knife_slash1.wav",
	"weapons/knife_slash2.wav",
	"weapons/knife_stab.wav",
	"player/death6.wav",
	"player/die1.wav",
	"player/die2.wav",
	"player/die3.wav",
}

//--------------------------------------------------------------------------------------------------
public plugin_precache()
{
	precache_model(headcrab_model_t)
	precache_model(headcrab_model_ct)
	precache_model(headcrab_t_knife)
	precache_model(headcrab_ct_knife)
	precache_model(headcrab_bomb)
	precache_model(headcrab_t_hegrenade)
	precache_model(headcrab_ct_hegrenade)
	precache_model(zombie_model_t)
	precache_model(zombie_model_ct)
	precache_model(zombie_knife)
	precache_model(bomb_model)
	precache_model(hegrenade_model)
	blood_drop = precache_model("sprites/blood.spr")
	blood_spray = precache_model("sprites/bloodspray.spr")
	
	precache_sound("headcrab/hc_attack2.wav")
	precache_sound("headcrab/hc_attack3.wav")
	precache_sound("headcrab/hc_die1.wav")
	precache_sound("headcrab/hc_die2.wav")
	precache_sound("headcrab/hc_headbite.wav")
	precache_sound("headcrab/hc_pain1.wav")
	precache_sound("headcrab/hc_pain2.wav")
	precache_sound("headcrab/hc_pain3.wav")
	precache_sound("headcrab/hc_idle3.wav")
	precache_sound("headcrab/hc_idle4.wav")
	precache_sound("headcrab/hc_idle5.wav")
	
	precache_sound("zombie/zo_attack1.wav")
	precache_sound("zombie/zo_attack2.wav")
	precache_sound("zombie/zo_pain1.wav")
	precache_sound("zombie/zo_pain2.wav")
	
	precache_sound("scientist/scream1.wav")
	precache_sound("scientist/scream2.wav")
	precache_sound("scientist/scream4.wav")
}
//--------------------------------------------------------------------------------------------------
public plugin_cfg()
{
	new configs[128], file[256]
	get_configsdir(configs, 126)
	format(file, 156, "%s/headcrabme/headcrabme.cfg", configs)
	
	if(file_exists(file))
		server_cmd("exec %s", file)
}
//--------------------------------------------------------------------------------------------------
public plugin_init()
{
	register_plugin(PLUGIN, VERSION, AUTHOR)
	
	//DON'T CHANGE HERE, USE "headcrabme.cfg"
	hc_switch = register_cvar("hc_switch", "1")
	hc_minhealth = register_cvar("hc_minhealth", "100")
	hc_health = register_cvar("hc_health", "300")
	hc_armor = register_cvar("hc_armor", "500")
	hc_speed = register_cvar("hc_speed", "1000")
	hc_gravity = register_cvar("hc_gravity", "45")
	hc_duck = register_cvar("hc_duck", "1")
	hc_infection = register_cvar("hc_infection", "1")
	hc_infect_hp = register_cvar("hc_infect_hp", "25")
	zm_health = register_cvar("zm_health", "600")
	zm_armor = register_cvar("zm_armor", "350")
	zm_speed = register_cvar("zm_speed", "300")
	zm_gravity = register_cvar("zm_gravity", "60")
	zm_infection = register_cvar("zm_infection", "1")
	zm_infect_hp = register_cvar("zm_infect_hp", "50")
	
	human_losefrags = register_cvar("human_losefrags", "1")
	hc_vision = register_cvar("hc_vision", "125")
	hc_red = register_cvar("hc_red", "255")
	hc_green = register_cvar("hc_green", "0")
	hc_blue = register_cvar("hc_blue", "0")
	hc_tint = register_cvar("hc_tint", "100")
	zm_vision = register_cvar("zm_vision", "150")
	zm_red = register_cvar("zm_red", "255")
	zm_green = register_cvar("zm_green", "0")
	zm_blue = register_cvar("zm_blue", "0")
	zm_tint = register_cvar("zm_tint", "150")
	
	hc_teams_mode = register_cvar("hc_teams_mode", "0")
	
	hc_sounds = register_cvar("hc_sounds", "1")
	
	amx_show_activity = get_cvar_pointer("amx_show_activity")
	
	register_forward(FM_EmitSound, "emitsound")
	
	register_clcmd("say /hcmmenu", "headcrabme_menu")
	register_clcmd("say /headcrabme", "headcrab_player")
	register_clcmd("say /unheadcrabme", "unheadcrab_player")
	
	register_clcmd("say_team /hcmmenu", "headcrabme_menu")
	register_clcmd("say_team /headcrabme", "headcrab_player")
	register_clcmd("say_team /unheadcrabme", "unheadcrab_player")
	
	register_concmd("hc_toggle", "hc_toggle", ADMINMENU_ACCESS, "<0|1> - Turns Head Crab Me plugin OFF/ON")
	register_concmd("hc_player", "hc_player", ADMINMENU_ACCESS, "<NAME|@TEAM|ALL> - Turns the target into a Head Crab")
	register_concmd("unhc_player", "unhc_player", ADMINMENU_ACCESS, "<NAME|@TEAM|ALL> - Turns the target back into a human and kills him")
	
	register_event("CurWeapon", "hc_weapons", "b")
	register_event("DeathMsg", "hc_death", "b")
	register_event("ResetHUD","hc_newspawn","b")
	
	register_event("HLTV", "hc_newround", "a", "1=0", "2=0")
	register_event("BarTime", "got_bomb", "be", "1=3")
	register_event("Damage", "hc_damage", "b")
	register_event("Battery", "detect_vip", "b", "1=200")
	register_event("DeathMsg","death_blood","a")
	register_event("Damage","dmg_blood","b","2!0","3=0","4!0")
	
	register_logevent("round_start", 2, "1=Round_Start")
	register_logevent("round_restart", 2, "1&Restart_Round_")
	register_logevent("round_end",   2, "1=Round_End")
	
	register_forward(FM_SetModel, "set_model")
	
	register_touch("weaponbox", "player", "cant_pickup")
	register_touch("armoury_entity", "player", "cant_pickup")
	register_touch("weapon_shield", "player", "cant_pickup")
	
	register_menucmd(register_menuid("[HCM menu]"),1023,"action_menu")
	
	MsgSetFOV = get_user_msgid("SetFOV")
	msgtext = get_user_msgid("StatusText")
	
	set_task(1.0, "setup_server")
	set_task(60.0, "announcement")
}
//--------------------------------------------------------------------------------------------------
public announcement()
{
	client_print(0, print_chat, "[HCM] This server is using 'Head Crab Me' plugin, type '/hcmmenu' to know what's up!")
}
//--------------------------------------------------------------------------------------------------
public emitsound(entity, channel, const sound[])
{
	if(!get_pcvar_num(hc_sounds) || entity > 32 || entity < 1 || (!g_headcrab[entity] && !g_zombie[entity]))
		return FMRES_IGNORED
	
	for(new i = 0; i < sizeof g_blockedsounds; ++i) {
		if(equali(sound, g_blockedsounds[i]))
			return FMRES_SUPERCEDE
	}
	return FMRES_IGNORED
}
//--------------------------------------------------------------------------------------------------
public remove_glow(id)
{
	set_user_rendering(id,kRenderFxNone,0,0,0,kRenderNormal,0)
}
//--------------------------------------------------------------------------------------------------
public detect_vip(id)
{
	VIP = id
}
//--------------------------------------------------------------------------------------------------
public setup_server()
{
	set_cvar_num("sv_maxspeed", 2000)
	set_cvar_num("sv_restart", 1)
}
//--------------------------------------------------------------------------------------------------
stock setScreenFlash(id, red, green, blue, decisecs, alpha)
{
	if (!is_user_connected(id)) return
	message_begin(MSG_ONE,get_user_msgid("ScreenFade"),{0,0,0},id)
	write_short( 1<<decisecs ) // fade lasts this long duration
	write_short( 1<<decisecs ) // fade lasts this long hold time
	write_short( 1<<12 ) // fade type (in / out)
	write_byte( red ) // fade red
	write_byte( green ) // fade green
	write_byte( blue ) // fade blue
	write_byte( alpha ) // fade alpha
	message_end()
}
//--------------------------------------------------------------------------------------------------
public hc_toggle(id, level, cid)
{
	if(!cmd_access(id, level, cid, 2))
		return PLUGIN_HANDLED
	
	new arg[21], val
	read_argv(1, arg, 20)
	val = str_to_num(arg)
	switch(val) {
		case 0: {
			if(!get_pcvar_num(hc_switch))
				console_print(id, "[HCM] Head Crab Me is already OFF!")
			else {
				set_pcvar_num(hc_switch, 0)
				console_print(id, "[HCM] Head Crab Me is now OFF!")
				client_print(0, print_chat, "[HCM] Head Crab Me is now OFF!")
				for(new i = 0; i < MAX_PLAYERS; ++i) {
					if(!is_user_alive(i))
						continue
					
					unheadcrab_player(i)
					unzombie_player(i)
					g_headcrab[i] = 0
					g_zombie[i] = 0
				}
				set_cvar_num("sv_restart", 3)
			}
		}
		case 1: {
			if(get_pcvar_num(hc_switch))
				console_print(id, "[HCM] Head Crab Me is already ON!")
			else {
				set_pcvar_num(hc_switch, 1)
				console_print(id, "[HCM] Head Crab Me is now ON!")
				client_print(0, print_chat, "[HCM] Head Crab Me is now ON!")
				set_cvar_num("sv_restart", 3)
			}
		}
		default: {
			console_print(id, "[HCM] Invalid value!")
			return PLUGIN_HANDLED
		}
	}
	return PLUGIN_HANDLED
}
//--------------------------------------------------------------------------------------------------
public hc_player(id, level, cid)
{
	if(!cmd_access(id, level, cid, 2))
		return PLUGIN_HANDLED
	
	if(!get_pcvar_num(hc_switch)) {
		console_print(id, "[HCM] Head Crab Me is OFF!")
		return PLUGIN_HANDLED
	}
	
	new arg1[32], name[32]
	read_argv(1, arg1, 31)
	get_user_name(id, name, 31)
	
	if(arg1[0] == '@') {
		new users[32], num
		get_players(users, num, "a")
		
		if(equali(arg1, "@T")) {
			for(new i = 0; i < MAX_PLAYERS; ++i) {
				if(!is_user_connected(i))
					continue
				
				if(cs_get_user_team(i) == CS_TEAM_T) {
					set_user_health(i, 100)
					headcrab_player(i)
				}
			}
			switch(get_pcvar_num(amx_show_activity)) {
				case 2:client_print(0, print_chat, "[HCM] ADMIN '%s' turned 'Terrorists' into Head Crabs!", name)
				case 1:client_print(0, print_chat, "[HCM] ADMIN turned 'Terrorists' into Head Crabs!")
			}
		}
		else if(equali(arg1, "@CT")) {
			for(new i = 0; i < MAX_PLAYERS; ++i) {
				if(!is_user_connected(i))
					continue
				
				if(cs_get_user_team(i) == CS_TEAM_CT) {
					set_user_health(i, 100)
					headcrab_player(i)
				}
			}
			switch(get_pcvar_num(amx_show_activity)) {
				case 2:client_print(0, print_chat, "[HCM] ADMIN '%s' turned 'Counter-Terrorists' into Head Crabs!", name)
				case 1:client_print(0, print_chat, "[HCM] ADMIN turned 'Counter-Terrorists' into Head Crabs!")
			}
		}
		else if(equali(arg1, "@VIP")) {
			new map[32]
			get_mapname(map, 31)

			if(!contain(map, "as_") && is_user_connected(VIP)) {
				set_user_health(VIP, 100)
				headcrab_player(VIP)
			}
			
			switch(get_pcvar_num(amx_show_activity)) {
				case 2:client_print(0, print_chat, "[HCM] ADMIN '%s' turned the 'VIP' into a Head Crab!", name)
				case 1:client_print(0, print_chat, "[HCM] ADMIN turned the 'VIP' into a Head Crab!")
			}
		}
	}
	else if(equali(arg1, "ALL")) {
		for(new i = 0; i < MAX_PLAYERS; ++i) {
			if(!is_user_connected(i))
				continue
			
			set_user_health(i, 100)
			headcrab_player(i)
		}
		switch(get_pcvar_num(amx_show_activity)) {
			case 2:client_print(0, print_chat, "[HCM] ADMIN '%s' turned everyone into Head Crabs!", name)
			case 1:client_print(0, print_chat, "[HCM] ADMIN turned everyone into Head Crabs!")
		}
	}
	else {
		new player = cmd_target(id, arg1, CMDTARGET_OBEY_IMMUNITY | CMDTARGET_ALLOW_SELF | CMDTARGET_ONLY_ALIVE)
	
		if (!player)
			return PLUGIN_HANDLED
		
		set_user_health(player, 100)
		headcrab_player(player)
		
		switch(get_pcvar_num(amx_show_activity)) {
			case 2:client_print(0, print_chat, "[HCM] ADMIN '%s' turned you into a Head Crab!", name)
			case 1:client_print(0, print_chat, "[HCM] ADMIN turned you into a Head Crab!")
		}
	}
	
	return PLUGIN_HANDLED
}
//--------------------------------------------------------------------------------------------------
public unhc_player(id, level, cid)
{
	if(!cmd_access(id, level, cid, 2))
		return PLUGIN_HANDLED
	
	if(!get_pcvar_num(hc_switch)) {
		console_print(id, "[HCM] Head Crab Me is OFF!")
		return PLUGIN_HANDLED
	}
	
	new arg1[32], name[32]
	read_argv(1, arg1, 31)
	get_user_name(id, name, 31)
	
	if(arg1[0] == '@') {
		new users[32], num
		get_players(users, num, "a")
		
		if(equali(arg1, "@T")) {
			for(new i = 0; i < MAX_PLAYERS; ++i) {
				if(!is_user_connected(i))
					continue
				
				if(cs_get_user_team(i) == CS_TEAM_T)
					unheadcrab_player(i)
			}
			switch(get_pcvar_num(amx_show_activity)) {
				case 2:client_print(0, print_chat, "[HCM] ADMIN '%s' turned 'Terrorists' back into humans!", name)
				case 1:client_print(0, print_chat, "[HCM] ADMIN turned 'Terrorists' back into humans!")
			}
		}
		else if(equali(arg1, "@CT")) {
			for(new i = 0; i < MAX_PLAYERS; ++i) {
				if(!is_user_alive(i))
					continue
				
				if(cs_get_user_team(i) == CS_TEAM_CT)
					unheadcrab_player(i)
			}
			switch(get_pcvar_num(amx_show_activity)) {
				case 2:client_print(0, print_chat, "[HCM] ADMIN '%s' turned 'Counter-Terrorists' back into humans!", name)
				case 1:client_print(0, print_chat, "[HCM] ADMIN turned 'Counter-Terrorists' back into humans!")
			}
		}
		else if(equali(arg1, "@VIP")) {
			new map[32]
			get_mapname(map, 31)

			if(!contain(map, "as_") && is_user_alive(VIP)) {
				set_user_health(VIP, 100)
				headcrab_player(VIP)
			}
			
			switch(get_pcvar_num(amx_show_activity)) {
				case 2:client_print(0, print_chat, "[HCM] ADMIN '%s' turned the 'VIP' back into a human!", name)
				case 1:client_print(0, print_chat, "[HCM] ADMIN turned the 'VIP' back into a human!")
			}
		}
	}
	else if(equali(arg1, "ALL")) {
		for(new i = 0; i < MAX_PLAYERS; ++i) {
			if(!is_user_alive(i))
				continue
			
			unheadcrab_player(i)
		}
		switch(get_pcvar_num(amx_show_activity)) {
			case 2:client_print(0, print_chat, "[HCM] ADMIN '%s' turned everyone back into humans!", name)
			case 1:client_print(0, print_chat, "[HCM] ADMIN turned everyone back into humans!")
		}
	}
	else {
		new player = cmd_target(id, arg1, CMDTARGET_OBEY_IMMUNITY | CMDTARGET_ALLOW_SELF | CMDTARGET_ONLY_ALIVE)
	
		if (!player)
			return PLUGIN_HANDLED
		
		unheadcrab_player(player)
		
		switch(get_pcvar_num(amx_show_activity)) {
			case 2:client_print(0, print_chat, "[HCM] ADMIN '%s' turned you back into a human!", name)
			case 1:client_print(0, print_chat, "[HCM] ADMIN turned you back into a human!")
		}
	}
	
	return PLUGIN_HANDLED
}
//--------------------------------------------------------------------------------------------------
public headcrabme_menu(id)
{
	if(!get_pcvar_num(hc_switch))
		return PLUGIN_HANDLED
	
	MenuID[id] = 1
	showhcm_menu(id)
	return PLUGIN_HANDLED
}
//--------------------------------------------------------------------------------------------------
public showhcm_menu(id)
{
	if(!get_pcvar_num(hc_switch))
		return PLUGIN_HANDLED
	
	new menu_body[320]
	new n = 0
	new len = 319
	new keys
	
	switch(MenuID[id]) {
		case 1: {
			n += format( menu_body[n],len-n,"\yHead Crab Me menu:\w^n^n")
	
			n += format( menu_body[n],len-n,"\y1.\w Show help^n")
			n += format( menu_body[n],len-n,"\y2.\w Show status^n")
			if(cmd_access(id, ADMIN_KICK, 0, 0))
				n += format( menu_body[n],len-n,"\y3.\w Admins menu^n")
			else
				n += format( menu_body[n],len-n,"\y3.\r Admins menu\w^n")
			n += format( menu_body[n],len-n,"\y4.\w Show commands^n")
			if(cmd_access(id, ADMIN_KICK, 0, 0))
				n += format( menu_body[n],len-n,"\y5.\w Show admin commands^n")
			else
				n += format( menu_body[n],len-n,"\y5.\r Show admin commands\w^n")
			
			keys = (1<<0)|(1<<1)
			if(cmd_access(id, ADMINMENU_ACCESS, 0, 0))
				keys |= (1<<2)
			keys |= (1<<3)
			if(cmd_access(id, ADMINMENU_ACCESS, 0, 0))
				keys |= (1<<4)
			keys |= (1<<9)
		}
	
		case 2: {
			new teamsmode[21], hcduck[21]
			switch(get_pcvar_num(hc_teams_mode)) {
				case 0: teamsmode = "OFF"
				case 1: teamsmode = "ON"
			}
			switch(get_pcvar_num(hc_duck)) {
				case 0: hcduck = "OFF"
				case 1: hcduck = "ON"
			}
			n += format( menu_body[n],len-n,"\yHead Crab Me status menu:\w^n^n")
	
			n += format( menu_body[n],len-n,"Teams Mode:\R\y%s\w^n", teamsmode)
			n += format( menu_body[n],len-n,"Head Crab min health:\R\y%d\w^n", get_pcvar_num(hc_minhealth))
			n += format( menu_body[n],len-n,"Head Crab duck:\R\y%s\w^n", hcduck)
			n += format( menu_body[n],len-n,"Head Crab health:\R\y%d\w^n", get_pcvar_num(hc_health))
			n += format( menu_body[n],len-n,"Head Crab armor:\R\y%d\w^n", get_pcvar_num(hc_armor))
			if(get_pcvar_num(hc_duck))
				n += format( menu_body[n],len-n,"Head Crab speed:\R\y%d - Duck\w^n", get_pcvar_num(hc_speed))
			else
				n += format( menu_body[n],len-n,"Head Crab speed:\R\y%d\w^n", get_pcvar_num(hc_speed))
			n += format( menu_body[n],len-n,"Head Crab gravity:\R\y%d / 100\w^n", get_pcvar_num(hc_gravity))
			
			n += format( menu_body[n],len-n,"\y^n8. Back")
			n += format( menu_body[n],len-n,"\y^n9. More^n")
		
			keys = (1<<7)|(1<<8)|(1<<9)
		}
		case 3: {
			new hcinfect[21], zminfect[21]
			switch(get_pcvar_num(hc_infection)) {
				case 0: hcinfect = "OFF"
				case 1: hcinfect = "ON"
			}
			switch(get_pcvar_num(zm_infection)) {
				case 0: zminfect = "OFF"
				case 1: zminfect = "ON"
			}
			n += format( menu_body[n],len-n,"\yHead Crab Me status menu:\w^n^n")
	
			n += format( menu_body[n],len-n,"Head Crab infection:\R\y%s\w^n", hcinfect)
			n += format( menu_body[n],len-n,"Head Crab infect hp:\R\y%d\w^n", get_pcvar_num(hc_infect_hp))
			n += format( menu_body[n],len-n,"Zombie health:\R\y%d\w^n", get_pcvar_num(zm_health))
			n += format( menu_body[n],len-n,"Zombie armor:\R\y%d\w^n", get_pcvar_num(zm_armor))
			n += format( menu_body[n],len-n,"Zombie speed:\R\y%d\w^n", get_pcvar_num(zm_speed))
			n += format( menu_body[n],len-n,"Zombie gravity:\R\y%d / 100\w^n", get_pcvar_num(zm_gravity))
			n += format( menu_body[n],len-n,"Zombie infection:\R\y%s\w^n", zminfect)
			n += format( menu_body[n],len-n,"Zombie infect hp:\R\y%d\w^n", get_pcvar_num(zm_infect_hp))
			
			n += format( menu_body[n],len-n,"\y^n8. Back")
			n += format( menu_body[n],len-n,"\y^n9. More^n")
		
			keys = (1<<7)|(1<<8)|(1<<9)
		}
		case 4: {
			n += format( menu_body[n],len-n,"\yHead Crab Me status menu:\w^n^n")
	
			n += format( menu_body[n],len-n,"Human Lose frags:\R\y%d\w^n", get_pcvar_num(human_losefrags))
			n += format( menu_body[n],len-n,"You will lose this amount of frags^n")
			n += format( menu_body[n],len-n,"if you used /unheadcrabme command.^n")
			
			n += format( menu_body[n],len-n,"\y^n8. Back^n")
		
			keys = (1<<7)|(1<<9)
		}
		case 5: {
			new teamsmode[21], hcduck[21]
			switch(get_pcvar_num(hc_teams_mode)) {
				case 0: teamsmode = "OFF"
				case 1: teamsmode = "ON"
			}
			switch(get_pcvar_num(hc_duck)) {
				case 0: hcduck = "OFF"
				case 1: hcduck = "ON"
			}
			n += format( menu_body[n],len-n,"\yHead Crab Me admins menu:\w^n^n")
	
			n += format( menu_body[n],len-n,"\y1.\w Teams Mode:\R\y%s\w^n", teamsmode)
			n += format( menu_body[n],len-n,"\y2.\w Head Crab min health:\R\y%d\w^n", get_pcvar_num(hc_minhealth))
			n += format( menu_body[n],len-n,"\y3.\w Head Crab duck:\R\y%s\w^n", hcduck)
			n += format( menu_body[n],len-n,"\y4.\w Head Crab health:\R\y%d\w^n", get_pcvar_num(hc_health))
			n += format( menu_body[n],len-n,"\y5.\w Head Crab armor:\R\y%d\w^n", get_pcvar_num(hc_armor))
			if(get_pcvar_num(hc_duck))
				n += format( menu_body[n],len-n,"\y6.\w Head Crab speed:\R\y%d - Duck\w^n", get_pcvar_num(hc_speed))
			else
				n += format( menu_body[n],len-n,"\y6.\w Head Crab speed:\R\y%d\w^n", get_pcvar_num(hc_speed))
			n += format( menu_body[n],len-n,"\y7.\w Head Crab gravity:\R\y%d / 100\w^n", get_pcvar_num(hc_gravity))
			
			n += format( menu_body[n],len-n,"\y^n8. Back")
			n += format( menu_body[n],len-n,"\y^n9. More^n")
		
			keys = (1<<0)|(1<<1)|(1<<2)|(1<<3)|(1<<4)|(1<<5)|(1<<6)|(1<<7)|(1<<8)|(1<<9)
		}
		case 6: {
			new hcinfect[21], zminfect[21]
			switch(get_pcvar_num(hc_infection)) {
				case 0: hcinfect = "OFF"
				case 1: hcinfect = "ON"
			}
			switch(get_pcvar_num(zm_infection)) {
				case 0: zminfect = "OFF"
				case 1: zminfect = "ON"
			}
			n += format( menu_body[n],len-n,"\yHead Crab Me admins menu:\w^n^n")
	
			n += format( menu_body[n],len-n,"\y1.\w Head Crab infection:\R\y%s\w^n", hcinfect)
			n += format( menu_body[n],len-n,"\y2.\w Head Crab infect hp:\R\y%d\w^n", get_pcvar_num(hc_infect_hp))
			n += format( menu_body[n],len-n,"\y3.\w Zombie health:\R\y%d\w^n", get_pcvar_num(zm_health))
			n += format( menu_body[n],len-n,"\y4.\w Zombie armor:\R\y%d\w^n", get_pcvar_num(zm_armor))
			n += format( menu_body[n],len-n,"\y5.\w Zombie speed:\R\y%d\w^n", get_pcvar_num(zm_speed))
			n += format( menu_body[n],len-n,"\y6.\w Zombie gravity:\R\y%d / 100\w^n", get_pcvar_num(zm_gravity))
			n += format( menu_body[n],len-n,"\y7.\w Zombie infection:\R\y%s\w^n", zminfect)
			
			n += format( menu_body[n],len-n,"\y^n8. Back")
			n += format( menu_body[n],len-n,"\y^n9. More^n")
		
			keys = (1<<0)|(1<<1)|(1<<2)|(1<<3)|(1<<4)|(1<<5)|(1<<6)|(1<<7)|(1<<8)|(1<<9)
		}
		case 7: {
			n += format( menu_body[n],len-n,"\yHead Crab Me admins menu:\w^n^n")
			
			n += format( menu_body[n],len-n,"\y1.\w Zombie infect hp:\R\y%d\w^n", get_pcvar_num(zm_infect_hp))
			n += format( menu_body[n],len-n,"\y2.\w Human Lose frags:\R\y%d\w^n", get_pcvar_num(human_losefrags))
			n += format( menu_body[n],len-n,"\y3.\w Head Crab vision:\R\y%d\w^n", get_pcvar_num(hc_vision))
			n += format( menu_body[n],len-n,"\y4.\w Head Crab vision red:\R\y%d\w^n", get_pcvar_num(hc_red))
			n += format( menu_body[n],len-n,"\y5.\w Head Crab vision green:\R\y%d\w^n", get_pcvar_num(hc_green))
			n += format( menu_body[n],len-n,"\y6.\w Head Crab vision blue:\R\y%d\w^n", get_pcvar_num(hc_blue))
			n += format( menu_body[n],len-n,"\y7.\w Head Crab vision tint:\R\y%d\w^n", get_pcvar_num(hc_tint))
			
			n += format( menu_body[n],len-n,"\y^n8. Back")
			n += format( menu_body[n],len-n,"\y^n9. More^n")
			
			keys = (1<<0)|(1<<1)|(1<<2)|(1<<3)|(1<<4)|(1<<5)|(1<<6)|(1<<7)|(1<<8)|(1<<9)
		}
		case 8: {
			n += format( menu_body[n],len-n,"\yHead Crab Me admins menu:\w^n^n")
			
			n += format( menu_body[n],len-n,"\y1.\w Zombie vision:\R\y%d\w^n", get_pcvar_num(zm_vision))
			n += format( menu_body[n],len-n,"\y2.\w Zombie vision red:\R\y%d\w^n", get_pcvar_num(zm_red))
			n += format( menu_body[n],len-n,"\y3.\w Zombie vision green:\R\y%d\w^n", get_pcvar_num(zm_green))
			n += format( menu_body[n],len-n,"\y4.\w Zombie vision blue:\R\y%d\w^n", get_pcvar_num(zm_blue))
			n += format( menu_body[n],len-n,"\y5.\w Zombie vision tint:\R\y%d\w^n", get_pcvar_num(zm_tint))
			
			n += format( menu_body[n],len-n,"\y^n8. Back^n")
			
			keys = (1<<0)|(1<<1)|(1<<2)|(1<<3)|(1<<4)|(1<<7)|(1<<9)
		}
		case 9: {
			n += format( menu_body[n],len-n,"\yHead Crab Me commands menu:\w^n^n")
			
			n += format( menu_body[n],len-n,"\ysay /headcrabme:\w Turns you into a Head Crab.^n")
			n += format( menu_body[n],len-n,"\ysay /unheadcrabme:\w Turns you back into a human.^n")
			
			n += format( menu_body[n],len-n,"\y^n8. Back^n")
			
			keys = (1<<7)|(1<<9)
		}
		case 10: {
			n += format( menu_body[n],len-n,"\yHead Crab Me admin commands menu:\w^n^n")
			n += format( menu_body[n],len-n,"\yhc_toggle:\w Turns Head Crab Me on and off.^n")
			n += format( menu_body[n],len-n,"\yhc_player:\w Turns the target into a Head Crab.^n")
			n += format( menu_body[n],len-n,"\yunhc_player:\w Turns the target back into a human.^n")
			
			n += format( menu_body[n],len-n,"\y^n8. Back^n")
			
			keys = (1<<7)|(1<<9)
		}
	}
	
	n += format( menu_body[n],len-n,"\y^n0. Exit")

	show_menu(id,keys,menu_body,-1,"[HCM menu]")
	return PLUGIN_HANDLED
}
//--------------------------------------------------------------------------------------------------
public action_menu(id,key)
{
	key++
	
	switch(MenuID[id]) {
		case 1: {
			switch(key) {
				case 1: {
					show_help(id)
					MenuID[id] = 0
					return PLUGIN_HANDLED
				}
				case 2: {
					MenuID[id] = 2
					showhcm_menu(id)
				}
				case 3: {
					MenuID[id] = 5
					showhcm_menu(id)
				}
				case 4: {
					MenuID[id] = 9
					showhcm_menu(id)
				}
				case 5: {
					MenuID[id] = 10
					showhcm_menu(id)
				}
				case 10: {
					MenuID[id] = 0
					return PLUGIN_HANDLED
				}
				default: showhcm_menu(id)
			}
		}
		case 2: {
			switch(key) {
				case 8: {
					MenuID[id] = 1
					showhcm_menu(id)
				}
				case 9: {
					MenuID[id] = 3
					showhcm_menu(id)
				}
				case 10: {
					MenuID[id] = 0
					return PLUGIN_HANDLED
				}
				default: showhcm_menu(id)
			}
		}
		case 3: {
			switch(key) {
				case 8: {
					MenuID[id] = 2
					showhcm_menu(id)
				}
				case 9: {
					MenuID[id] = 4
					showhcm_menu(id)
				}
				case 10: {
					MenuID[id] = 0
					return PLUGIN_HANDLED
				}
				default: showhcm_menu(id)
			}
		}
		case 4: {
			switch(key) {
				case 8: {
					MenuID[id] = 3
					showhcm_menu(id)
				}
				case 10: {
					MenuID[id] = 0
					return PLUGIN_HANDLED
				}
				default: showhcm_menu(id)
			}
		}
		case 5: {
			switch(key) {
				case 1: {
					teamsmode_toggle()
					showhcm_menu(id)
				}
				case 2: {
					hcminhp_change()
					showhcm_menu(id)
				}
				case 3: {
					hcduck_toggle()
					showhcm_menu(id)
				}
				case 4: {
					hchealth_change()
					showhcm_menu(id)
				}
				case 5: {
					hcarmor_change()
					showhcm_menu(id)
				}
				case 6: {
					hcspeed_change()
					showhcm_menu(id)
				}
				case 7: {
					hcgravity_change()
					showhcm_menu(id)
				}
				case 8: {
					MenuID[id] = 1
					showhcm_menu(id)
				}
				case 9: {
					MenuID[id] = 6
					showhcm_menu(id)
				}
				case 10: {
					MenuID[id] = 0
					return PLUGIN_HANDLED
				}
				default: showhcm_menu(id)
			}
		}
		case 6: {
			switch(key) {
				case 1: {
					hcinfect_toggle()
					showhcm_menu(id)
				}
				case 2: {
					hcinfecthp_change()
					showhcm_menu(id)
				}
				case 3: {
					zmhealth_change()
					showhcm_menu(id)
				}
				case 4: {
					zmarmor_change()
					showhcm_menu(id)
				}
				case 5: {
					zmspeed_change()
					showhcm_menu(id)
				}
				case 6: {
					zmgravity_change()
					showhcm_menu(id)
				}
				case 7: {
					zminfect_toggle()
					showhcm_menu(id)
				}
				case 8: {
					MenuID[id] = 5
					showhcm_menu(id)
				}
				case 9: {
					MenuID[id] = 7
					showhcm_menu(id)
				}
				case 10: {
					MenuID[id] = 0
					return PLUGIN_HANDLED
				}
				default: showhcm_menu(id)
			}
		}
		case 7: {
			switch(key) {
				case 1: {
					zminfecthp_change()
					showhcm_menu(id)
				}
				case 2: {
					humanlose_change()
					showhcm_menu(id)
				}
				case 3: {
					hcvision_change()
					showhcm_menu(id)
				}
				case 4: {
					hcred_change()
					showhcm_menu(id)
				}
				case 5: {
					hcgreen_change()
					showhcm_menu(id)
				}
				case 6: {
					hcblue_change()
					showhcm_menu(id)
				}
				case 7: {
					hctint_change()
					showhcm_menu(id)
				}
				case 8: {
					MenuID[id] = 6
					showhcm_menu(id)
				}
				case 9: {
					MenuID[id] = 8
					showhcm_menu(id)
				}
				case 10: {
					MenuID[id] = 0
					return PLUGIN_HANDLED
				}
				default: showhcm_menu(id)
			}
		}
		case 8: {
			switch(key) {
				case 1: {
					zmvision_change()
					showhcm_menu(id)
				}
				case 2: {
					zmred_change()
					showhcm_menu(id)
				}
				case 3: {
					zmgreen_change()
					showhcm_menu(id)
				}
				case 4: {
					zmblue_change()
					showhcm_menu(id)
				}
				case 5: {
					zmtint_change()
					showhcm_menu(id)
				}
				case 8: {
					MenuID[id] = 7
					showhcm_menu(id)
				}
				case 10: {
					MenuID[id] = 0
					return PLUGIN_HANDLED
				}
				default: showhcm_menu(id)
			}
		}
		case 9: {
			switch(key) {
				case 8: {
					MenuID[id] = 1
					showhcm_menu(id)
				}
				case 10: {
					MenuID[id] = 0
					return PLUGIN_HANDLED
				}
				default: showhcm_menu(id)
			}
		}
		case 10: {
			switch(key) {
				case 8: {
					MenuID[id] = 1
					showhcm_menu(id)
				}
				case 10: {
					MenuID[id] = 0
					return PLUGIN_HANDLED
				}
				default: showhcm_menu(id)
			}
		}
	}
	
	return PLUGIN_HANDLED
}
//--------------------------------------------------------------------------------------------------
public teamsmode_toggle()
{
	switch(get_pcvar_num(hc_teams_mode)) {
		case 0: {
			set_pcvar_num(hc_teams_mode, 1)
			client_print(0, print_chat, "[HCM] Teams Mode is now ON!")
			set_cvar_num("sv_restart", 3)
		}
		case 1: {
			set_pcvar_num(hc_teams_mode, 0)
			client_print(0, print_chat, "[HCM] Teams Mode is now OFF!")
			set_cvar_num("sv_restart", 3)
		}
	}
}
//--------------------------------------------------------------------------------------------------
public hcminhp_change()
{
	new minhealth = get_pcvar_num(hc_minhealth) + HCMINHEALTH_ADD
	if(minhealth > 100)
		set_pcvar_num(hc_minhealth, 0)
	else
		set_pcvar_num(hc_minhealth, minhealth)
}
//--------------------------------------------------------------------------------------------------
public hcduck_toggle()
{
	switch(get_pcvar_num(hc_duck)) {
		case 0: {
			set_pcvar_num(hc_duck, 1)
			client_print(0, print_chat, "[HCM] Duck Mode is now ON!")
		}
		case 1: {
			set_pcvar_num(hc_duck, 0)
			client_print(0, print_chat, "[HCM] Duck Mode is now OFF!")
		}
	}
}
//--------------------------------------------------------------------------------------------------
public hchealth_change()
{
	new health = get_pcvar_num(hc_health) + HCHEALTH_ADD
	if(health > 1000)
		set_pcvar_num(hc_health, 100)
	else
		set_pcvar_num(hc_health, health)
}
//--------------------------------------------------------------------------------------------------
public hcarmor_change()
{
	new armor = get_pcvar_num(hc_armor) + HCARMOR_ADD
	if(armor > 1000)
		set_pcvar_num(hc_armor, 100)
	else
		set_pcvar_num(hc_armor, armor)
}
//--------------------------------------------------------------------------------------------------
public hcspeed_change()
{
	new speed = get_pcvar_num(hc_speed) + HCSPEED_ADD
	if(speed > 2000)
		set_pcvar_num(hc_speed, 0)
	else
		set_pcvar_num(hc_speed, speed)
	
	for(new i = 0; i < MAX_PLAYERS; ++i) {
		if(!is_user_alive(i))
			continue
		
		if(!freezetime)
			set_user_maxspeed(i, get_pcvar_float(hc_speed))
	}
}
//--------------------------------------------------------------------------------------------------
public hcgravity_change()
{
	new gravity = get_pcvar_num(hc_gravity) + HCGRAVITY_ADD
	if(gravity > 100)
		set_pcvar_num(hc_gravity, 0)
	else
		set_pcvar_num(hc_gravity, gravity)
	
	for(new i = 0; i < MAX_PLAYERS; ++i) {
		if(!is_user_alive(i))
			continue
		
		entity_set_float(i, EV_FL_gravity, get_pcvar_float(hc_gravity)  / 100.0)
	}
}
//--------------------------------------------------------------------------------------------------
public hcinfect_toggle()
{
	switch(get_pcvar_num(hc_infection)) {
		case 0: {
			set_pcvar_num(hc_infection, 1)
			client_print(0, print_chat, "[HCM] Head Crab Infection Mode is now ON!")
		}
		case 1: {
			set_pcvar_num(hc_infection, 0)
			client_print(0, print_chat, "[HCM] Head Crab Infection Mode is now OFF!")
		}
	}
}
//--------------------------------------------------------------------------------------------------
public hcinfecthp_change()
{
	new hp = get_pcvar_num(hc_infect_hp) + HCINFECTHP_ADD
	if(hp > 100)
		set_pcvar_num(hc_infect_hp, 0)
	else
		set_pcvar_num(hc_infect_hp, hp)
}
//--------------------------------------------------------------------------------------------------
public zmhealth_change()
{
	new health = get_pcvar_num(zm_health) + ZMHEALTH_ADD
	if(health > 1000)
		set_pcvar_num(zm_health, 100)
	else
		set_pcvar_num(zm_health, health)
}
//--------------------------------------------------------------------------------------------------
public zmarmor_change()
{
	new armor = get_pcvar_num(zm_armor) + ZMARMOR_ADD
	if(armor > 1000)
		set_pcvar_num(zm_armor, 100)
	else
		set_pcvar_num(zm_armor, armor)
}
//--------------------------------------------------------------------------------------------------
public zmspeed_change()
{
	new speed = get_pcvar_num(zm_speed) + ZMSPEED_ADD
	if(speed > 2000)
		set_pcvar_num(zm_speed, 0)
	else
		set_pcvar_num(zm_speed, speed)
	
	for(new i = 0; i < MAX_PLAYERS; ++i) {
		if(!is_user_alive(i))
			continue
		
		if(!freezetime)
			set_user_maxspeed(i, get_pcvar_float(zm_speed))
	}
}
//--------------------------------------------------------------------------------------------------
public zmgravity_change()
{
	new gravity = get_pcvar_num(zm_gravity) + ZMGRAVITY_ADD
	if(gravity > 100)
		set_pcvar_num(zm_gravity, 0)
	else
		set_pcvar_num(zm_gravity, gravity)
	
	for(new i = 0; i < MAX_PLAYERS; ++i) {
		if(!is_user_alive(i))
			continue
		
		entity_set_float(i, EV_FL_gravity, get_pcvar_float(zm_gravity)  / 100.0)
	}
}
//--------------------------------------------------------------------------------------------------
public zminfect_toggle()
{
	switch(get_pcvar_num(zm_infection)) {
		case 0: {
			set_pcvar_num(zm_infection, 1)
			client_print(0, print_chat, "[HCM] Zombie Infection Mode is now ON!")
		}
		case 1: {
			set_pcvar_num(zm_infection, 0)
			client_print(0, print_chat, "[HCM] Zombie Infection Mode is now OFF!")
		}
	}
}
//--------------------------------------------------------------------------------------------------
public zminfecthp_change()
{
	new hp = get_pcvar_num(zm_infect_hp) + ZMINFECTHP_ADD
	if(hp > 100)
		set_pcvar_num(zm_infect_hp, 0)
	else
		set_pcvar_num(zm_infect_hp, hp)
}
//--------------------------------------------------------------------------------------------------
public humanlose_change()
{
	new frags = get_pcvar_num(human_losefrags) + HUMANLOSE_ADD
	if(frags > 10)
		set_pcvar_num(human_losefrags, 0)
	else
		set_pcvar_num(human_losefrags, frags)
}
//--------------------------------------------------------------------------------------------------
public hcvision_change()
{
	new vision = get_pcvar_num(hc_vision) + HCVISION_ADD
	if(vision > 150)
		set_pcvar_num(hc_vision, 100)
	else
		set_pcvar_num(hc_vision, vision)
}
//--------------------------------------------------------------------------------------------------
public hcred_change()
{
	new red = get_pcvar_num(hc_red) + HCRED_ADD
	if(red > 255)
		set_pcvar_num(hc_red, 0)
	else
		set_pcvar_num(hc_red, red)
}
//--------------------------------------------------------------------------------------------------
public hcgreen_change()
{
	new green = get_pcvar_num(hc_green) + HCGREEN_ADD
	if(green > 255)
		set_pcvar_num(hc_green, 0)
	else
		set_pcvar_num(hc_green, green)
}
//--------------------------------------------------------------------------------------------------
public hcblue_change()
{
	new blue = get_pcvar_num(hc_blue) + HCBLUE_ADD
	if(blue > 255)
		set_pcvar_num(hc_blue, 0)
	else
		set_pcvar_num(hc_blue, blue)
}
//--------------------------------------------------------------------------------------------------
public hctint_change()
{
	new tint = get_pcvar_num(hc_tint) + HCBLUE_ADD
	if(tint > 255)
		set_pcvar_num(hc_tint, 0)
	else
		set_pcvar_num(hc_tint, tint)
}
//--------------------------------------------------------------------------------------------------
public zmvision_change()
{
	new vision = get_pcvar_num(zm_vision) + ZMVISION_ADD
	if(vision > 150)
		set_pcvar_num(zm_vision, 100)
	else
		set_pcvar_num(zm_vision, vision)
}
//--------------------------------------------------------------------------------------------------
public zmred_change()
{
	new red = get_pcvar_num(zm_red) + ZMRED_ADD
	if(red > 255)
		set_pcvar_num(zm_red, 0)
	else
		set_pcvar_num(zm_red, red)
}
//--------------------------------------------------------------------------------------------------
public zmgreen_change()
{
	new green = get_pcvar_num(zm_green) + ZMGREEN_ADD
	if(green > 255)
		set_pcvar_num(zm_green, 0)
	else
		set_pcvar_num(zm_green, green)
}
//--------------------------------------------------------------------------------------------------
public zmblue_change()
{
	new blue = get_pcvar_num(zm_blue) + ZMBLUE_ADD
	if(blue > 255)
		set_pcvar_num(zm_blue, 0)
	else
		set_pcvar_num(zm_blue, blue)
}
//--------------------------------------------------------------------------------------------------
public zmtint_change()
{
	new tint = get_pcvar_num(zm_tint) + ZMBLUE_ADD
	if(tint > 255)
		set_pcvar_num(zm_tint, 0)
	else
		set_pcvar_num(zm_tint, tint)
}
//--------------------------------------------------------------------------------------------------
public show_help(id) {
	show_motd( id, "/addons/amxmodx/configs/headcrabme/hcmhelp.txt", "Head Crab Me Help" )  
}
//--------------------------------------------------------------------------------------------------
public hc_damage(id)
{
	if(!get_pcvar_num(hc_switch))
		return PLUGIN_HANDLED
	
	if(g_headcrab[id] || g_zombie[id])
		return PLUGIN_HANDLED
	
	new attacker = get_user_attacker(id)
	
	if(!attacker || attacker >= MAX_PLAYERS)
		return PLUGIN_HANDLED
	
	if(g_headcrab[attacker])
		emit_sound(id, CHAN_STATIC, "headcrab/hc_headbite.wav", 1.0, ATTN_NORM, 0, PITCH_NORM)
	
	if(!g_headcrab[attacker] && !g_zombie[attacker])
		return PLUGIN_HANDLED
	
	new CsTeams:player_team, players[32], num
	player_team = cs_get_user_team(id)
	if(player_team == CS_TEAM_T)
		get_players(players, num, "ae", "TERRORIST")
	else if(player_team == CS_TEAM_CT)
		get_players(players, num, "ae", "CT")
	if(num <= 1)
		return PLUGIN_HANDLED
	
	if(is_user_alive(id) && id != attacker) {
		if(get_pcvar_num(hc_infection) && g_headcrab[attacker] && get_user_health(id) <= get_pcvar_num(hc_infect_hp)) {
			new infector[32], victim[32]
			get_user_name(attacker, infector, 31)
			get_user_name(id, victim, 31)
			set_user_frags(attacker, get_user_frags(attacker) + 1)
			cs_set_user_deaths(attacker, cs_get_user_deaths(id))
			client_print(0, print_chat, "[HCM] Head Crab '%s' infected '%s'!", infector, victim)
			zombie_player(id)
			return PLUGIN_HANDLED
		}
		if(get_pcvar_num(zm_infection) && g_zombie[attacker] && get_user_health(id) <= get_pcvar_num(zm_infect_hp)) {
			new infector[32], victim[32]
			get_user_name(attacker, infector, 31)
			get_user_name(id, victim, 31)
			set_user_frags(attacker, get_user_frags(attacker) + 1)
			cs_set_user_deaths(attacker, cs_get_user_deaths(id))
			client_print(0, print_chat, "[HCM] Zombie '%s' infected '%s'!", infector, victim)
			zombie_player(id)
			return PLUGIN_HANDLED
		}
	}
	return PLUGIN_HANDLED
}
//--------------------------------------------------------------------------------------------------
public client_command(id)
{
	if(!get_pcvar_num(hc_switch))
		return PLUGIN_CONTINUE
	
	new cmd[32], arg[32]
	read_argv(0, cmd, 31)
	read_argv(1, arg, 31)
	if(equali(arg, "/headcrabme")) {
		if(get_pcvar_num(hc_teams_mode)) { 
			client_print(id, print_chat, "[HCM] You can't use that command in teams mode!")
			return PLUGIN_HANDLED
		}
		if(!is_user_alive(id)) {
			client_print(id, print_chat, "[HCM] You can't use that command when you're dead!")
			return PLUGIN_HANDLED
		}
	}
	else if(equali(arg, "/unheadcrabme")) {
		if(get_pcvar_num(hc_teams_mode)) {
			client_print(id, print_chat, "[HCM] You can't use that command in teams mode!")
			return PLUGIN_HANDLED
		}
		if(!is_user_alive(id)) {
			client_print(id, print_chat, "[HCM] You can't use that command when you're dead!")
			return PLUGIN_HANDLED
		}
	}
	
	return PLUGIN_CONTINUE
}
//--------------------------------------------------------------------------------------------------
public headcrab_player(id)
{
	if(!get_pcvar_num(hc_switch) || g_headcrab[id] || g_zombie[id])
		return PLUGIN_HANDLED
	
	if(get_user_health(id) < get_pcvar_num(hc_minhealth)) {
		client_print(id, print_chat, "[HCM] You don't have '%d' health!", get_pcvar_num(hc_minhealth))
		return PLUGIN_HANDLED
	}
	
	switch(cs_get_user_team(id)) {
		case CS_TEAM_T: cs_set_user_model(id, shorthc_model_t)
		case CS_TEAM_CT: cs_set_user_model(id, shorthc_model_ct)
	}
	
	if(get_pcvar_num(hc_sounds))
		client_cmd(id, "speak sound/headcrab/hc_headbite")
	
	client_print(id, print_chat, "[HCM] You've turned into a Head Crab!")
	setScreenFlash(id, get_pcvar_num(hc_red), get_pcvar_num(hc_green), get_pcvar_num(hc_blue), 10, 255)
	set_headcrab_atribs(id)
	
	return PLUGIN_HANDLED
}
//--------------------------------------------------------------------------------------------------
public unheadcrab_player(id)
{
	if(!get_pcvar_num(hc_switch) || !g_headcrab[id])
		return PLUGIN_HANDLED
	
	if(is_user_alive(id)) {
		new iOrigin[3]
		get_user_origin(id,iOrigin)
		// Effects
		fx_blood_red(iOrigin)
		fx_blood_red(iOrigin)
		fx_blood_red(iOrigin)
		fx_bleed_red(iOrigin)
		fx_bleed_red(iOrigin)
		fx_headshot_red(iOrigin)
		set_user_rendering(id,kRenderFxGlowShell,255,0,0,kRenderNormal,16)
		set_task(3.0, "remove_glow", id)
	}
	
	cs_reset_user_model(id)
	client_print(id, print_chat, "[HCM] You've turned back into a human!")
	if(!get_pcvar_num(hc_teams_mode)) {
		user_silentkill(id)
		set_user_frags(id, get_user_frags(id) - get_pcvar_num(human_losefrags))
	}
	client_cmd(id, "cl_forwardspeed 400; cl_backspeed 400; cl_sidespeed 400")
	
	g_headcrab[id] = 0
	if(get_pcvar_num(hc_duck)) {
		set_pev(id, pev_bInDuck, 0)
		client_cmd(id, "-duck")
		client_cmd(id, "-duck")		//This is to prevent death cam menu after death
	}
	
	if(get_pcvar_num(hc_sounds))
		client_cmd(id, "speak sound/headcrab/hc_headbite")
	
	message_begin(MSG_ONE, MsgSetFOV, {0,0,0}, id)
	write_byte(100)
	message_end()
	
	if(is_user_alive(id)) {
		engclient_cmd(id, "weapon_knife")
		entity_set_string(id, EV_SZ_viewmodel, "models/v_knife.mdl")
		if(!freezetime)
			set_user_maxspeed(id, 250.0)
		if(get_user_health(id) > 100)
			set_user_health(id, 100)
		entity_set_float(id, EV_FL_gravity, 1.0)
	}
	
	set_task(0.1, "hc_check_hitzones", id)
	
	return PLUGIN_HANDLED
}
//--------------------------------------------------------------------------------------------------
public set_headcrab_atribs(id)
{
	if(!get_pcvar_num(hc_switch))
		return PLUGIN_HANDLED
	
	g_headcrab[id] = 1
	
	client_cmd(id, "cl_forwardspeed 2000; cl_backspeed 2000; cl_sidespeed 2000")
	
	if(!is_user_alive(id))
		return PLUGIN_HANDLED
	
	new iOrigin[3]
	get_user_origin(id,iOrigin)
	// Effects
	fx_blood_red(iOrigin)
	fx_blood_red(iOrigin)
	fx_blood_red(iOrigin)
	fx_bleed_red(iOrigin)
	fx_bleed_red(iOrigin)
	fx_headshot_red(iOrigin)
	
	set_user_rendering(id,kRenderFxGlowShell,255,0,0,kRenderNormal,16)
	set_task(3.0, "remove_glow", id)
	
	set_user_health(id, get_pcvar_num(hc_health))
	cs_set_user_armor(id, get_pcvar_num(hc_armor), CS_ARMOR_KEVLAR)
	set_task(0.1, "speed_check", id)
	entity_set_float(id, EV_FL_gravity, get_pcvar_float(hc_gravity)  / 100.0)
	
	if(get_pcvar_num(hc_duck) && !is_user_bot(id)) {
		set_pev(id, pev_bInDuck, 1)
		console_cmd(id, "+duck")
	}
	
	new Zoom = get_pcvar_num(hc_vision)

	if ( Zoom < 100 )
	{
		Zoom = 100
		set_pcvar_num(hc_vision, Zoom)
	}
	
	message_begin(MSG_ONE, MsgSetFOV, {0,0,0}, id)
	write_byte(Zoom)
	message_end()
	
	set_task(1.0, "hc_vision_loop", id, "", 0, "b")
	set_task(0.1, "hc_check_hitzones", id)
	if(get_pcvar_num(hc_sounds))
		set_task(30.0, "idle_sound", id, "", 0, "b")
	
	hc_weapons(id)
	
	return PLUGIN_HANDLED
}
//--------------------------------------------------------------------------------------------------
public idle_sound(id)
{
	if(!get_pcvar_num(hc_sounds) || !g_headcrab[id] || !is_user_alive(id)) {
		remove_task(id)
		return
	}
	
	new sound = random_num(1, 3)
	switch(sound) {
		case 1: emit_sound(id, CHAN_STATIC, "headcrab/hc_idle3.wav", 1.0, ATTN_NORM, 0, PITCH_NORM)
		case 2: emit_sound(id, CHAN_STATIC, "headcrab/hc_idle4.wav", 1.0, ATTN_NORM, 0, PITCH_NORM)
		case 3: emit_sound(id, CHAN_STATIC, "headcrab/hc_idle5.wav", 1.0, ATTN_NORM, 0, PITCH_NORM)
	}
}
//--------------------------------------------------------------------------------------------------
public hc_check_hitzones(id)
{
	if(!is_user_alive(id))
		return
	
	if(g_headcrab[id]) {
		set_user_hitzones(0, id, 192)
		set_user_footsteps(id, 1)
	}
	else {
		set_user_hitzones(0, id, 255)
		set_user_footsteps(id, 0)
	}
}
//--------------------------------------------------------------------------------------------------
public zombie_player(id)
{
	if(!get_pcvar_num(hc_switch) || g_headcrab[id] || g_zombie[id] || !is_user_alive(id))
		return PLUGIN_HANDLED
	
	client_print(id, print_chat, "[HCM] You've turned into a Zombie!")
	setScreenFlash(id, get_pcvar_num(zm_red), get_pcvar_num(zm_green), get_pcvar_num(zm_blue), 10, 255)
	team[id] = cs_get_user_team(id)
	if(team[id] == CS_TEAM_T)
		cs_set_user_team(id, CS_TEAM_CT)
	else if(team[id] == CS_TEAM_CT)
		cs_set_user_team(id, CS_TEAM_T)
	
	new sound = random_num(1, 3)
	switch(sound) {
		case 1: emit_sound(id, CHAN_STATIC, "scientist/scream1.wav", 1.0, ATTN_NORM, 0, PITCH_NORM)
		case 2: emit_sound(id, CHAN_STATIC, "scientist/scream2.wav", 1.0, ATTN_NORM, 0, PITCH_NORM)
		case 3: emit_sound(id, CHAN_STATIC, "scientist/scream4.wav", 1.0, ATTN_NORM, 0, PITCH_NORM)
	}
	
	set_task(7.0, "loop_breathe", id, "", 0, "b")
	set_zombie_atribs(id)
	
	return PLUGIN_HANDLED
}
//--------------------------------------------------------------------------------------------------
public loop_breathe(id)
{
	if(!is_user_alive(id) || !g_zombie[id]) {
		client_cmd(id, "stopsound")
		remove_task(id)
		return
	}
	
	client_cmd(id, "speak player/breathe1")
}
//--------------------------------------------------------------------------------------------------
public unzombie_player(id)
{
	if(!get_pcvar_num(hc_switch) || !g_zombie[id])
		return PLUGIN_HANDLED
	
	cs_set_user_team(id, team[id])
	cs_reset_user_model(id)
	if(is_user_alive(id)) {
		set_user_rendering(id,kRenderFxGlowShell,255,0,0,kRenderNormal,16)
		set_task(3.0, "remove_glow", id)
		client_print(id, print_chat, "[HCM] You've turned back into a human!")
		user_silentkill(id)
	}
	client_cmd(id, "cl_forwardspeed 400; cl_backspeed 400; cl_sidespeed 400")
	
	new iOrigin[3]
	get_user_origin(id,iOrigin)
	// Effects
	fx_blood_red(iOrigin)
	fx_blood_red(iOrigin)
	fx_blood_red(iOrigin)
	fx_bleed_red(iOrigin)
	fx_bleed_red(iOrigin)
	
	g_zombie[id] = 0
	
	return PLUGIN_HANDLED
}
//--------------------------------------------------------------------------------------------------
public set_zombie_atribs(id)
{
	if(!get_pcvar_num(hc_switch))
		return PLUGIN_HANDLED
	
	g_zombie[id] = 1
	
	client_cmd(id, "cl_forwardspeed 2000; cl_backspeed 2000; cl_sidespeed 2000")
	
	new iOrigin[3]
	get_user_origin(id,iOrigin)
	// Effects
	fx_blood_red(iOrigin)
	fx_blood_red(iOrigin)
	fx_blood_red(iOrigin)
	fx_bleed_red(iOrigin)
	fx_bleed_red(iOrigin)
	
	set_user_rendering(id,kRenderFxGlowShell,255,0,0,kRenderNormal,16)
	set_task(3.0, "remove_glow", id)
	
	switch(cs_get_user_team(id)) {
		case CS_TEAM_T: cs_set_user_model(id, shortzm_model_t)
		case CS_TEAM_CT: cs_set_user_model(id, shortzm_model_ct)
	}
	
	set_user_health(id, get_pcvar_num(zm_health))
	cs_set_user_armor(id, get_pcvar_num(zm_armor), CS_ARMOR_KEVLAR)
	set_task(0.1, "speed_check", id)
	entity_set_float(id, EV_FL_gravity, get_pcvar_float(zm_gravity)  / 100.0)
	
	new Zoom = get_pcvar_num(zm_vision)

	if ( Zoom < 100 )
	{
		Zoom = 100
		set_pcvar_num(zm_vision, Zoom)
	}
	
	message_begin(MSG_ONE, MsgSetFOV, {0,0,0}, id)
	write_byte(Zoom)
	message_end()
	
	set_task(1.0, "hc_vision_loop", id, "", 0, "b")
	
	hc_weapons(id)
	
	return PLUGIN_HANDLED
}
//--------------------------------------------------------------------------------------------------
public speed_check(id)
{
	if(!get_pcvar_num(hc_switch) || freezetime)
		return PLUGIN_HANDLED
	
	if(g_headcrab[id]) {
		set_user_maxspeed(id, get_pcvar_float(hc_speed))
		if(is_user_bot(id) && get_pcvar_num(hc_duck))
			set_user_maxspeed(id, get_pcvar_float(hc_speed) / 3)
	}
	else if(g_zombie[id])
		set_user_maxspeed(id, get_pcvar_float(zm_speed))
	return PLUGIN_HANDLED
}
//--------------------------------------------------------------------------------------------------
public hc_vision_loop(id) {
	if(!get_pcvar_num(hc_switch))
		return PLUGIN_HANDLED
		
	if ( !is_user_connected(id) )
	{
		remove_task(id)
		return PLUGIN_HANDLED
	}
	
	if((g_headcrab[id] || g_zombie[id]) && cs_get_user_shield(id)) {
		engclient_cmd(id, "drop", "weapon_shield")
		hc_weapons(id)
	}
	
	if ( g_headcrab[id] && is_user_alive(id) )
	{
		setScreenFlash(id, get_pcvar_num(hc_red), get_pcvar_num(hc_green), get_pcvar_num(hc_blue), 10, get_pcvar_num(hc_tint))
		switch(cs_get_user_team(id)) {
			case CS_TEAM_T: cs_set_user_model(id, shorthc_model_t)
			case CS_TEAM_CT: cs_set_user_model(id, shorthc_model_ct)
		}
		set_task(0.1, "speed_check", id)
		new Zoom = get_pcvar_num(hc_vision)

		if ( Zoom < 100 )
		{
			Zoom = 100
			set_pcvar_num(hc_vision, Zoom)
		}
	
		message_begin(MSG_ONE, MsgSetFOV, {0,0,0}, id)
		write_byte(Zoom)
		message_end()
		new HUD[51]
		format(HUD,50,"Health: %i Armor: %i",get_user_health(id),get_user_armor(id))
		message_begin(MSG_ONE, msgtext, {0,0,0}, id)
		write_byte(0)
		write_string(HUD)
		message_end()
	}
	else if ( g_zombie[id] && is_user_alive(id) )
	{
		setScreenFlash(id, get_pcvar_num(zm_red), get_pcvar_num(zm_green), get_pcvar_num(zm_blue), 10, get_pcvar_num(zm_tint))
		switch(cs_get_user_team(id)) {
			case CS_TEAM_T: cs_set_user_model(id, shortzm_model_t)
			case CS_TEAM_CT: cs_set_user_model(id, shortzm_model_ct)
		}
		set_task(0.1, "speed_check", id)
		new Zoom = get_pcvar_num(zm_vision)

		if ( Zoom < 100 )
		{
			Zoom = 100
			set_pcvar_num(zm_vision, Zoom)
		}
	
		message_begin(MSG_ONE, MsgSetFOV, {0,0,0}, id)
		write_byte(Zoom)
		message_end()
		new HUD[51]
		format(HUD,50,"Health: %i Armor: %i",get_user_health(id),get_user_armor(id))
		message_begin(MSG_ONE, msgtext, {0,0,0}, id)
		write_byte(0)
		write_string(HUD)
		message_end()
	}
	return PLUGIN_CONTINUE
}
//--------------------------------------------------------------------------------------------------
public hc_weapons(id)
{
	if(!get_pcvar_num(hc_switch))
		return PLUGIN_HANDLED
		
	if(!is_user_alive(id) || !g_headcrab[id] && !g_zombie[id]) return PLUGIN_HANDLED
	
	if(cs_get_user_shield(id)) {
		engclient_cmd(id, "drop", "weapon_shield")
		engclient_cmd(id, "weapon_knife")
	}
	
	new ammo, clip, wpnid = get_user_weapon(id, ammo, clip)
	new weapons[MAX_WEAPONS], num
	new wp
	
	get_user_weapons(id, weapons, num)
	for (new i=0; i<num; i++){
		wp = weapons[i]
		
		if(g_zombie[id]) {
			if(wp == CSW_C4) {
				new wpnname[32]
				get_weaponname(wp, wpnname, 31)
				engclient_cmd(id, "drop", wpnname)
			}
		}
	}
	
	if(g_headcrab[id]) {
		if(wpnid != CSW_KNIFE && wpnid != CSW_C4 && wpnid != CSW_HEGRENADE) {
			engclient_cmd(id, "weapon_knife")
		}
	}
	
	else if(g_zombie[id]) {
		if(wpnid != CSW_KNIFE) {
			engclient_cmd(id, "weapon_knife")
		}
	}
	
	if(g_headcrab[id]) {
		set_task(0.3, "check_view_model", id)
		entity_set_string(id, EV_SZ_viewmodel, "")
		set_pev(id, pev_weaponmodel2, "")
		set_task(0.1, "speed_check", id)
		entity_set_float(id, EV_FL_gravity, get_pcvar_float(hc_gravity)  / 100.0)
		if(get_pcvar_num(hc_duck) && !is_user_bot(id)) {
			set_pev(id, pev_bInDuck, 1)
			console_cmd(id, "+duck")
		}
	}
	
	else if(g_zombie[id]) {
		entity_set_string(id, EV_SZ_viewmodel, zombie_knife)
		set_pev(id, pev_weaponmodel2, "")
		set_task(0.1, "speed_check", id)
		entity_set_float(id, EV_FL_gravity, get_pcvar_float(zm_gravity)  / 100.0)
	}
	
	return PLUGIN_CONTINUE
}
//--------------------------------------------------------------------------------------------------
public check_view_model(id)
{
	new ammo, clip, wpnid = get_user_weapon(id, ammo, clip)
	new CsTeams:team_model = cs_get_user_team(id)
	
	switch(team_model) {
		case CS_TEAM_T: {
			if(wpnid == CSW_KNIFE)
				entity_set_string(id, EV_SZ_viewmodel, headcrab_t_knife)
			else if(wpnid == CSW_C4)
				entity_set_string(id, EV_SZ_viewmodel, headcrab_bomb)
			else if(wpnid == CSW_HEGRENADE)
				entity_set_string(id, EV_SZ_viewmodel, headcrab_t_hegrenade)
			else {
				engclient_cmd(id, "weapon_knife")
				entity_set_string(id, EV_SZ_viewmodel, headcrab_t_knife)
			}
		}
		case CS_TEAM_CT: {
			if(wpnid == CSW_KNIFE)
				entity_set_string(id, EV_SZ_viewmodel, headcrab_ct_knife)
			else if(wpnid == CSW_HEGRENADE)
				entity_set_string(id, EV_SZ_viewmodel, headcrab_ct_hegrenade)
			else {
				engclient_cmd(id, "weapon_knife")
				entity_set_string(id, EV_SZ_viewmodel, headcrab_ct_knife)
			}
		}
	}
}
//--------------------------------------------------------------------------------------------------
public hc_death(id)
{
	if(is_user_alive(id))
		return PLUGIN_HANDLED
	
	set_pev(id, pev_bInDuck, 0)
	console_cmd(id, "-duck")
	console_cmd(id, "-duck")
	
	client_cmd(id, "stopsound")
	return PLUGIN_HANDLED
}
//--------------------------------------------------------------------------------------------------
public hc_newspawn(id)
{
	fx_trans(id, 1000)
	
	if(g_headcrab[id]) {
		set_user_health(id, get_pcvar_num(hc_health))
		set_user_armor(id, get_pcvar_num(hc_armor))
	}
	else if(get_user_armor(id) > 100) {
		cs_set_user_armor(id, 0, CS_ARMOR_NONE)
	}
	
	if(get_pcvar_num(hc_teams_mode) && latejoin)
		set_task(0.1, "silent_death", id)
	
	set_task(0.1, "hc_check_hitzones", id)
}
//--------------------------------------------------------------------------------------------------
public silent_death(id)
{
	set_user_origin(id, {0,0,-10000})
	user_silentkill(id)
	client_print(id, print_chat, "[HCM] You joined late in teams mode! (Silent Death)")
}
//--------------------------------------------------------------------------------------------------
public round_start()
{
	freezetime = false
}
//--------------------------------------------------------------------------------------------------
public hc_newround()
{
	freezetime = true
	latejoin = 0
	if(get_pcvar_num(hc_teams_mode))
		set_task(0.1, "setup_teams")
}
//--------------------------------------------------------------------------------------------------
public setup_teams()
{
	new CsTeams:player_team
	if(equali(hc_teamturn, "CT")) {
		client_print(0, print_chat, "[HCM] Teams Mode: It's 'Counter-Terrorists' turn!")
		for(new i = 0; i < MAX_PLAYERS; i++) {
			if(is_user_alive(i)) {
				player_team = cs_get_user_team(i)
				if(player_team == CS_TEAM_CT)
					headcrab_player(i)
			}
		}
		hc_teamturn = "T"
	}
	else if(equali(hc_teamturn, "T")) {
		client_print(0, print_chat, "[HCM] Teams Mode: It's 'Terrorists' turn!")
		for(new i = 0; i < MAX_PLAYERS; i++) {
			if(is_user_alive(i)) {
				player_team = cs_get_user_team(i)
				if(player_team == CS_TEAM_T)
					headcrab_player(i)
			}
		}
		hc_teamturn = "CT"
	}
	latejoin = 1
}
//--------------------------------------------------------------------------------------------------
public round_restart()
{
	for(new i = 0; i < MAX_PLAYERS; i++) {
		unzombie_player(i)
		unheadcrab_player(i)
	}
}
//--------------------------------------------------------------------------------------------------
public round_end()
{
	for(new i = 0; i < MAX_PLAYERS; i++) {
		if(g_zombie[i])
			unzombie_player(i)
		if(g_headcrab[i] && get_pcvar_num(hc_teams_mode))
			unheadcrab_player(i)
	}
}
//--------------------------------------------------------------------------------------------------
public client_PreThink(id)
{
	if(!get_pcvar_num(hc_switch) || !is_user_alive(id))
		return PLUGIN_CONTINUE
	
	if(g_headcrab[id] && get_pcvar_num(hc_duck) && !is_user_bot(id)) {
		set_pev(id, pev_bInDuck, 1)
		console_cmd(id, "+duck")
	}
	
	static button
	button = pev(id, pev_button)
	if(get_pcvar_num(hc_sounds) && !g_sound[id] && ((button & IN_ATTACK2) || (button & IN_JUMP))) {
		g_sound[id] = 1
		set_task(2.0, "reset_sound", id)
		new sound = random_num(1, 2)
		if(g_headcrab[id]) {
			switch(sound) {
				case 1: emit_sound(id, CHAN_STATIC, "headcrab/hc_attack2.wav", 1.0, ATTN_NORM, 0, PITCH_NORM)
				case 2: emit_sound(id, CHAN_STATIC, "headcrab/hc_attack3.wav", 1.0, ATTN_NORM, 0, PITCH_NORM)
			}
		}
		else if(g_zombie[id]) {
			switch(sound) {
				case 1: emit_sound(id, CHAN_STATIC, "zombie/zo_attack1.wav", 1.0, ATTN_NORM, 0, PITCH_NORM)
				case 2: emit_sound(id, CHAN_STATIC, "zombie/zo_attack2.wav", 1.0, ATTN_NORM, 0, PITCH_NORM)
			}
		}
		
	}
	
	if(g_zombie[id] && block_use[id])
		set_pev(id, pev_button, pev(id, pev_button ) & ~IN_USE )
	
	return PLUGIN_CONTINUE
}
//--------------------------------------------------------------------------------------------------
public reset_sound(id)
{
	g_sound[id] = 0
}
//--------------------------------------------------------------------------------------------------
public client_disconnect(id)
{
	g_headcrab[id] = 0
	g_zombie[id] = 0
	set_task(0.1, "hc_check_hitzones", id)
}
//--------------------------------------------------------------------------------------------------
public bomb_defusing(id)
{
	if(g_zombie[id]) {
		block_use[id] = 1
		engclient_cmd(id, "-use")
		client_print(id, print_chat, "[HCM] Zombies can't defuse bombs!")
		set_task(2.0, "unblock_use", id)
	}
}
//--------------------------------------------------------------------------------------------------
public unblock_use(id)
{
	block_use[id] = 0
}
//--------------------------------------------------------------------------------------------------
public got_bomb(id)
{	
	if(g_headcrab[id])
	{
		bomber = id
	}
	else
	{
		bomber = 0
	}
}
//--------------------------------------------------------------------------------------------------
public set_model(edict, const model[])
{
	if (!is_valid_ent(edict))
		return FMRES_IGNORED

	new id = entity_get_edict(edict, EV_ENT_owner)
	if(equali(model, "models/w_c4.mdl") && g_headcrab[bomber])
	{
		entity_set_model(edict, bomb_model)
		return FMRES_SUPERCEDE
	}
	if(equali(model, "models/w_hegrenade.mdl") && g_headcrab[id])
	{
		entity_set_model(edict, hegrenade_model)
		return FMRES_SUPERCEDE
	}
	return FMRES_IGNORED
}
//--------------------------------------------------------------------------------------------------
public cant_pickup(ent, id)
{
	if(!get_pcvar_num(hc_switch))
		return PLUGIN_CONTINUE
	
	if(g_headcrab[id]) {
		new model[52]
		entity_get_string(ent, EV_SZ_model, model, 51)
		if(!equali(model, "models/w_backpack.mdl") && !equali(model, "models/w_hegrenade.mdl"))
			return PLUGIN_HANDLED
	}
	
	if(g_zombie[id])
		return PLUGIN_HANDLED
	
	return PLUGIN_CONTINUE
}
//--------------------------------------------------------------------------------------------------
static fx_trans(player,amount)
{
	set_user_rendering(player,kRenderFxNone,0,0,0,kRenderTransAlpha,amount)
	return PLUGIN_CONTINUE
}
//--------------------------------------------------------------------------------------------------
public fx_blood_red(origin[3])
{
	message_begin(MSG_BROADCAST,SVC_TEMPENTITY)
	write_byte(115)
	write_coord(origin[0]+random_num(-20,20))
	write_coord(origin[1]+random_num(-20,20))
	write_coord(origin[2]+random_num(-20,20))
	write_short(blood_spray)
	write_short(blood_drop)
	write_byte(248)
	write_byte(15)
	message_end()
}
//--------------------------------------------------------------------------------------------------
public fx_blood_green(origin[3])
{
	message_begin(MSG_BROADCAST,SVC_TEMPENTITY)
	write_byte(115)
	write_coord(origin[0]+random_num(-10,10))
	write_coord(origin[1]+random_num(-10,10))
	write_coord(origin[2]+random_num(-25,-15))
	write_short(blood_spray)
	write_short(blood_drop)
	write_byte(192)
	write_byte(10)
	message_end()
}
//--------------------------------------------------------------------------------------------------
public fx_bleed_red(origin[3])
{
	// Blood spray
	message_begin(MSG_BROADCAST,SVC_TEMPENTITY)
	write_byte(101)
	write_coord(origin[0])
	write_coord(origin[1])
	write_coord(origin[2]+10)
	write_coord(random_num(-100,100))
	write_coord(random_num(-100,100))
	write_coord(random_num(-10,10))
	write_byte(70)
	write_byte(random_num(50,100))
	message_end()
}
//--------------------------------------------------------------------------------------------------
public fx_bleed_green(origin[3])
{
	// Blood spray
	message_begin(MSG_BROADCAST,SVC_TEMPENTITY)
	write_byte(101)
	write_coord(origin[0])
	write_coord(origin[1])
	write_coord(origin[2])
	write_coord(random_num(-100,100))
	write_coord(random_num(-100,100))
	write_coord(random_num(-10,10))
	write_byte(192)
	write_byte(random_num(50,100))
	message_end()
}
//--------------------------------------------------------------------------------------------------
static fx_blood_small_green(origin[3],num)
{
	if(is_running("czero"))
		return PLUGIN_CONTINUE
	
	static const blood_small[6] = {3,4,5,6,7,8}
	
	for (new j = 0; j < num; j++) {
		message_begin(MSG_BROADCAST,SVC_TEMPENTITY)
		write_byte(116)
		write_coord(origin[0]+random_num(-65,65))
		write_coord(origin[1]+random_num(-65,65))
		write_coord(origin[2]-36)
		write_byte(blood_small[random_num(0,5)])
		message_end()
	}
	return PLUGIN_CONTINUE
}
//--------------------------------------------------------------------------------------------------
static fx_blood_large_green(origin[3],num)
{
	if(is_running("czero"))
		return PLUGIN_CONTINUE
	
	static const blood_large[2] = {26,27}

	for (new i = 0; i < num; i++) {
		message_begin(MSG_BROADCAST,SVC_TEMPENTITY)
		write_byte(116)
		write_coord(origin[0]+random_num(-45,45))
		write_coord(origin[1]+random_num(-45,45))
		write_coord(origin[2]-36)
		write_byte(blood_large[random_num(0,1)])
		message_end()
	}
	return PLUGIN_CONTINUE
}
//--------------------------------------------------------------------------------------------------
public fx_headshot_red(origin[3])
{
	for (new i = 0; i < 5; i++) {
		message_begin(MSG_BROADCAST,SVC_TEMPENTITY)
		write_byte(101)
		write_coord(origin[0])
		write_coord(origin[1])
		write_coord(origin[2]+30)
		write_coord(random_num(-20,20)) // x
		write_coord(random_num(-20,20)) // y
		write_coord(random_num(50,300)) // z
		write_byte(70) // color
		write_byte(random_num(25,50)) // speed
		message_end()
	}
}
//--------------------------------------------------------------------------------------------------
public fx_headshot_green(origin[3])
{
	// Blood spray, 8 times
	for (new i = 0; i < 8; i++) {
		message_begin(MSG_BROADCAST,SVC_TEMPENTITY)
		write_byte(101)
		write_coord(origin[0])
		write_coord(origin[1])
		write_coord(origin[2]-25)
		write_coord(random_num(-20,20)) // x
		write_coord(random_num(-20,20)) // y
		write_coord(random_num(50,300)) // z
		write_byte(192) // color
		write_byte(random_num(100,200)) // speed
		message_end()
	}
}
//--------------------------------------------------------------------------------------------------
public dmg_blood()
{
	new id = read_data(0)
	if(is_user_alive(id))
	{
		new origin[3]
		get_user_origin(id,origin)
		if(g_headcrab[id]) {
			fx_blood_green(origin)
			fx_blood_small_green(origin,3)
			if(get_pcvar_num(hc_sounds) && !g_sound[id]) {
				g_sound[id] = 1
				set_task(2.0, "reset_sound", id)
				new sound = random_num(1, 3)
				switch(sound) {
					case 1: emit_sound(id, CHAN_STATIC, "headcrab/hc_pain1.wav", 1.0, ATTN_NORM, 0, PITCH_NORM)
					case 2: emit_sound(id, CHAN_STATIC, "headcrab/hc_pain2.wav", 1.0, ATTN_NORM, 0, PITCH_NORM)
					case 3: emit_sound(id, CHAN_STATIC, "headcrab/hc_pain3.wav", 1.0, ATTN_NORM, 0, PITCH_NORM)
				}
			}
		}
		else if(g_zombie[id]) {
			if(get_pcvar_num(hc_sounds) && !g_sound[id]) {
				g_sound[id] = 1
				set_task(2.0, "reset_sound", id)
				new sound = random_num(1, 2)
				switch(sound) {
					case 1: emit_sound(id, CHAN_STATIC, "zombie/zo_pain1.wav", 1.0, ATTN_NORM, 0, PITCH_NORM)
					case 2: emit_sound(id, CHAN_STATIC, "zombie/zo_pain2.wav", 1.0, ATTN_NORM, 0, PITCH_NORM)
				}
			}
		}
	}
}
//--------------------------------------------------------------------------------------------------
public death_blood()
{
	new iOrigin[3]
	new sWeapon[32]
	new id = read_data(2)
	
	read_data(4,sWeapon,31)
	
	if(!g_headcrab[id])
		return
	
	get_user_origin(id,iOrigin)
	
	if (equali(sWeapon,"grenade")) {
		// Effects
		fx_blood_green(iOrigin)
		fx_blood_green(iOrigin)
		fx_blood_green(iOrigin)
		fx_bleed_green(iOrigin)
		fx_bleed_green(iOrigin)
		fx_headshot_green(iOrigin)
		fx_trans(id, 0)
		fx_blood_large_green(iOrigin, 10)
		fx_blood_small_green(iOrigin, 25)
		iOrigin[2] = iOrigin[2] - 20
		set_user_origin(id, iOrigin)
	}
	fx_blood_green(iOrigin)
	fx_blood_green(iOrigin)
	fx_bleed_green(iOrigin)
	fx_blood_small_green(iOrigin, 12)
	fx_blood_large_green(iOrigin, 5)
	if(get_pcvar_num(hc_sounds)) {
		new sound = random_num(1, 2)
		switch(sound) {
			case 1: emit_sound(id, CHAN_STATIC, "headcrab/hc_die1.wav", 1.0, ATTN_NORM, 0, PITCH_NORM)
			case 2: emit_sound(id, CHAN_STATIC, "headcrab/hc_die2.wav", 1.0, ATTN_NORM, 0, PITCH_NORM)
		}
	}
}
//--------------------------------------------------------------------------------------------------
/* AMXX-Studio Notes - DO NOT MODIFY BELOW HERE
*{\\ rtf1\\ fbidis\\ ansi\\ ansicpg1252\\ deff0{\\ fonttbl{\\ f0\\ fnil\\ fcharset0 Tahoma;}}\n\\ viewkind4\\ uc1\\ pard\\ ltrpar\\ lang1025\\ f0\\ fs16 \n\\ par }
*/
